#[repr(C)]pub struct AsyncRingLayout {
pub sq_base: u64,
pub cq_base: u64,
pub sq_size: u64,
pub cq_size: u64,
pub entries: u32,
pub _reserved: u32,
}Expand description
Layout descriptor for async I/O ring buffers.
Describes the submission and completion queue regions within a shared memory page used by the async I/O subsystem.
Fields
sq_base: u64Physical address of the submission queue base.
cq_base: u64Physical address of the completion queue base.
sq_size: u64Size of the submission queue in bytes.
cq_size: u64Size of the completion queue in bytes.
entries: u32Number of entries in each queue.
_reserved: u32Trait Implementations
Sourceimpl Clone for AsyncRingLayout
impl Clone for AsyncRingLayout
Sourcefn clone(&self) -> AsyncRingLayout
fn clone(&self) -> AsyncRingLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AsyncRingLayout
Sourceimpl Debug for AsyncRingLayout
impl Debug for AsyncRingLayout
Sourceimpl FromBytes for AsyncRingLayout
impl FromBytes for AsyncRingLayout
Sourceimpl FromZeros for AsyncRingLayout
impl FromZeros for AsyncRingLayout
Sourceimpl IntoBytes for AsyncRingLayout
impl IntoBytes for AsyncRingLayout
fn as_mut_bytes(&mut self) -> &mut [u8]where
Self: FromBytes,
fn as_mut_bytes(&mut self) -> &mut [u8]where
Self: FromBytes,
Gets the bytes of this value mutably. Read more
Sourceimpl TryFromBytes for AsyncRingLayout
impl TryFromBytes for AsyncRingLayout
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,