SiloMode

Struct SiloMode 

#[repr(transparent)]
pub struct SiloMode(pub u16);
9-bit octal silo permission mode (3 control + 3 hardware + 3 registry).

Shared ABI type used by both kernel and userspace init. The kernel’s richer OctalMode (with typed bitflag fields) is built from this via OctalMode::from_octal(val.0).

Bit layout: [control:3][hardware:3][registry:3] (LSB = registry).

Example: 0o777 = full permissions in all groups.

Tuple Fields

0: u16

Implementations

Source

impl SiloMode

pub const fn is_subset_of(&self, other: &SiloMode) -> bool

Return true if self bits are a subset of other’s bits (i.e. self does not request any permission other lacks).