#[repr(C)]pub struct ReadReply {
pub status: u32,
pub count: u32,
}Expand description
Read reply prefix (variable-length data follows at offset 8).
Wire layout:
status @ 0..4, count @ 4..8, data @ 8...
The data field contains count bytes of file content.
Fields
status: u32Status code: 0 = success.
count: u32Number of data bytes written starting at offset 8.